@@ -3,11 +3,13 @@ import arrow
 from django.core.exceptions import ValidationError
 from django.utils.timezone import get_default_timezone
 
-from ..exceptions import FutureDateError
-
 from .date import date_not_future
 
 
+class FutureDateError(Exception):
+    pass
+
+
 def dob_not_future(value):
     """this is unreliable as the DoB is more likely relative to something like the report_datetime
     and not today."""
